@@ -11,7 +11,6 @@ define(['appSettings', 'userSettings', 'appStorage', 'datetime'], function (appS
         self.currentItem = null;
         self.currentMediaSource = null;
 
-        self.currentDurationTicks = null;
         self.startTimeTicksOffset = null;
 
         self.playlist = [];
@@ -144,11 +143,31 @@ define(['appSettings', 'userSettings', 'appStorage', 'datetime'], function (appS
                 return true;
             }
 
-            // viblast can help us here
-            //return true;
-            return window.MediaSource && !browserInfo.firefox;
+            return window.MediaSource != null;
         };
 
+        function getProfileOptions(item) {
+
+            var disableVideoAudioCodecs = [];
+            if (!AppInfo.isNativeApp && !item.RunTimeTicks) {
+                disableVideoAudioCodecs.push('ac3');
+            }
+
+            var options = {};
+
+            if (!AppInfo.isNativeApp) {
+                options.enableMkvProgressive = item.RunTimeTicks != null;
+
+                if (item.RunTimeTicks == null) {
+                    options.enableHls = true;
+                }
+
+                options.disableVideoAudioCodecs = disableVideoAudioCodecs;
+            }
+
+            return options;
+        }
+
         self.changeStream = function (ticks, params) {
 
             var mediaRenderer = self.currentMediaRenderer;
@@ -166,7 +185,7 @@ define(['appSettings', 'userSettings', 'appStorage', 'datetime'], function (appS
             var playSessionId = getParameterByName('PlaySessionId', currentSrc);
             var liveStreamId = getParameterByName('LiveStreamId', currentSrc);
 
-            Dashboard.getDeviceProfile().then(function (deviceProfile) {
+            Dashboard.getDeviceProfile(null, getProfileOptions(self.currentMediaSource)).then(function (deviceProfile) {
 
                 var audioStreamIndex = params.AudioStreamIndex == null ? (getParameterByName('AudioStreamIndex', currentSrc) || null) : params.AudioStreamIndex;
                 if (typeof (audioStreamIndex) == 'string') {
@@ -264,6 +283,22 @@ define(['appSettings', 'userSettings', 'appStorage', 'datetime'], function (appS
             //self.updateTextStreamUrls(streamInfo.startTimeTicksOffset || 0);
         };
 
+        self.getSeekableDurationTicks = function () {
+
+            if (self.currentMediaSource && self.currentMediaSource.RunTimeTicks) {
+                return self.currentMediaSource.RunTimeTicks;
+            }
+
+            if (self.currentMediaRenderer) {
+                var duration = self.currentMediaRenderer.duration();
+                if (duration) {
+                    return duration * 10000;
+                }
+            }
+
+            return null;
+        };
+
         self.setCurrentTime = function (ticks, positionSlider, currentTimeElement) {
 
             // Convert to ticks
@@ -272,13 +307,15 @@ define(['appSettings', 'userSettings', 'appStorage', 'datetime'], function (appS
             var timeText = datetime.getDisplayRunningTime(ticks);
             var mediaRenderer = self.currentMediaRenderer;
 
-            if (self.currentDurationTicks) {
+            var seekableDurationTicks = self.getSeekableDurationTicks();
 
-                timeText += " / " + datetime.getDisplayRunningTime(self.currentDurationTicks);
+            if (seekableDurationTicks) {
+
+                timeText += " / " + datetime.getDisplayRunningTime(seekableDurationTicks);
 
                 if (positionSlider) {
 
-                    var percent = ticks / self.currentDurationTicks;
+                    var percent = ticks / seekableDurationTicks;
                     percent *= 100;
 
                     positionSlider.value = percent;
@@ -287,7 +324,7 @@ define(['appSettings', 'userSettings', 'appStorage', 'datetime'], function (appS
 
             if (positionSlider) {
 
-                positionSlider.disabled = !((self.currentDurationTicks || 0) > 0 || canPlayerSeek());
+                positionSlider.disabled = !((seekableDurationTicks || 0) > 0 || canPlayerSeek());
             }
 
             if (currentTimeElement) {
@@ -655,7 +692,8 @@ define(['appSettings', 'userSettings', 'appStorage', 'datetime'], function (appS
             }
 
             var onBitrateDetected = function () {
-                Dashboard.getDeviceProfile().then(function (deviceProfile) {
+
+                Dashboard.getDeviceProfile(null, getProfileOptions(item)).then(function (deviceProfile) {
                     playOnDeviceProfileCreated(deviceProfile, item, startPosition, callback);
                 });
             };
@@ -1516,7 +1554,6 @@ define(['appSettings', 'userSettings', 'appStorage', 'datetime'], function (appS
                 Events.on(mediaRenderer, "timeupdate", onTimeUpdate);
 
                 self.currentMediaRenderer = mediaRenderer;
-                self.currentDurationTicks = self.currentMediaSource.RunTimeTicks;
 
                 mediaRenderer.init().then(function () {
 
